searchData={"items":[{"type":"module","title":"CookieMonster","doc":"A simple HTTP Cookie encoder and decoder written in pure Elixir with zero\ndependencies.\n\nFollows the standards for cookie headers described in MDN:\nhttps://developer.mozilla.org/en-US/docs/Web/HTTP/Cookies","ref":"CookieMonster.html"},{"type":"function","title":"CookieMonster.decode/1","doc":"Decodes a Set-Cookie header text into an Elixir struct","ref":"CookieMonster.html#decode/1"},{"type":"function","title":"Example - CookieMonster.decode/1","doc":"iex> header = \"id=a3fWa; Expires=Wed, 21 Oct 2015 07:28:00 GMT; Secure; HttpOnly\"\n    ...> {:ok, cookie} = CookieMonster.decode(header)\n    ...> cookie\n    %CookieMonster.Cookie{\n      value: \"a3fWa\",\n      expires: ~U[2015-10-21 07:28:00Z],\n      http_only: true,\n      name: \"id\",\n      secure: true\n    }","ref":"CookieMonster.html#decode/1-example"},{"type":"function","title":"CookieMonster.decode!/1","doc":"Decodes a Set-Cookie Header into an Elixir struct\n\nSimilar to `decode/1` except it will unwrap the error tuple and raise\nin case of errors.","ref":"CookieMonster.html#decode!/1"},{"type":"function","title":"CookieMonster.encode/1","doc":"","ref":"CookieMonster.html#encode/1"},{"type":"function","title":"CookieMonster.encode/2","doc":"Encodes a cookie struct into a header string","ref":"CookieMonster.html#encode/2"},{"type":"function","title":"Example - CookieMonster.encode/2","doc":"iex> cookie = %CookieMonster.Cookie{\n    ...>   name: \"id\",\n    ...>   value: \"a3fWa\",\n    ...>   expires: ~U[2015-10-21 07:28:00Z],\n    ...>   http_only: true,\n    ...>   secure: true\n    ...> }\n    iex> CookieMonster.encode(cookie)\n    {:ok, \"id=a3fWa; Expires=Wed, 21 Oct 2015 07:28:00 GMT; HttpOnly; Secure\"}","ref":"CookieMonster.html#encode/2-example"},{"type":"function","title":"CookieMonster.encode!/2","doc":"","ref":"CookieMonster.html#encode!/2"},{"type":"module","title":"CookieMonster.Cookie","doc":"Data Structure for representing a cookie in Elixir","ref":"CookieMonster.Cookie.html"},{"type":"type","title":"CookieMonster.Cookie.t/0","doc":"","ref":"CookieMonster.Cookie.html#t:t/0"},{"type":"extras","title":"CookieMonster","doc":"# CookieMonster\n\n![Build Status](https://github.com/dkarter/cookie_monster/actions/workflows/elixir.yml/badge.svg)\n\nA simple HTTP Cookie encoder and decoder in pure Elixir with zero runtime dependencies[^1].\n\n![cookie monster logo](img/cookie_monster.png)","ref":"readme.html"},{"type":"extras","title":"Motivation - CookieMonster","doc":"I recently worked on an app that needed to parse cookies. Initially I reached\nout for [Plug](https://hex.pm/packages/plug)'s implementation to encode\nand decode the cookies, but that meant bringing in a (relatively) large dependency just to use a small portion of it (my application was not web facing).\n\nAnother issue I had with Plug's implementation is that it used the name of the cookie as a map key in the decoding result:\n\n```elixir\n\"hello=a3fWa; Expires=Wed, 21 Oct 2015 07:28:00 GMT; HttpOnly; Secure\"\n|> Plug.Conn.Cookies.decode()\n\n# => %{\"Expires\" => \"Wed, 21 Oct 2015 07:28:00 GMT\", \"hello\" => \"a3fWa\"}\n```\n\nI wanted something a little simpler, and dependency free that makes it easy to extract the name and\nvalue. As a bonus, I wanted to decode the date into an Elixir native DateTime\nso that I can easily check if a cookie is expired.","ref":"readme.html#motivation"},{"type":"extras","title":"Example - CookieMonster","doc":"##","ref":"readme.html#example"},{"type":"extras","title":"Encoding - CookieMonster","doc":"```elixir\nalias CookieMonster.Cookie\n\n%Cookie{\n  name: \"id\",\n  value: \"a3fWa\",\n  expires: ~U[2015-10-21 07:28:00Z],\n  http_only: true,\n  secure: true\n}\n|> CookieMonster.encode!()\n\n# => \"id=a3fWa; Expires=Wed, 21 Oct 2015 07:28:00 GMT; HttpOnly; Secure\"\n```\n\n##","ref":"readme.html#encoding"},{"type":"extras","title":"Decoding - CookieMonster","doc":"```elixir\nalias CookieMonster.Cookie\n\n\"id=a3fWa; Expires=Wed, 21 Oct 2015 07:28:00 GMT; HttpOnly; Secure\"\n|> CookieMonster.decode!()\n\n# => %Cookie{name: \"id\", value: \"a3fWa\", expires: ~U[2015-10-21 07:28:00Z], http_only: true, secure: true}\n```","ref":"readme.html#decoding"},{"type":"extras","title":"Installation - CookieMonster","doc":"The package can be installed by adding `cookie_monster` to your list of\ndependencies in `mix.exs`:\n\n \n\n```elixir\ndef deps do\n  [\n    {:cookie_monster, \"~> 1.1.2\"}\n  ]\nend\n```\n\n \n\nThe docs can be found at [https://hexdocs.pm/cookie_monster](https://hexdocs.pm/cookie_monster).\n\n[^1]: Boundary is listed as a dependency, but it is not a runtime dependency and only used during compile time to ensure proper design","ref":"readme.html#installation"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [1.1.2](https://github.com/dkarter/cookie_monster/compare/v1.1.1...v1.1.2) (2023-10-15)\n\n\n#","ref":"changelog.html"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* automatically publish docs with hex package ([af3c87d](https://github.com/dkarter/cookie_monster/commit/af3c87ddf943eb2efbc31eb7dba1bece1479cc4b))\n\n## [1.1.1](https://github.com/dkarter/cookie_monster/compare/v1.1.0...v1.1.1) (2023-10-15)\n\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* support dashes in expiration format RFC1123 ([#10](https://github.com/dkarter/cookie_monster/issues/10)) ([81e081a](https://github.com/dkarter/cookie_monster/commit/81e081ab5b45a7da866b02436e90aea11668c83b))\n\n## [1.1.0](https://github.com/dkarter/cookie_monster/compare/v1.0.0...v1.1.0) (2023-10-15)\n\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Features - Changelog","doc":"* add support for all valid expiration datetime formats ([#8](https://github.com/dkarter/cookie_monster/issues/8)) ([d0c17f7](https://github.com/dkarter/cookie_monster/commit/d0c17f7cbf6fd92caf234f9807be0e81dd39ee4a))","ref":"changelog.html#features"},{"type":"extras","title":"1.0.0 (2023-10-15) - Changelog","doc":"#","ref":"changelog.html#1-0-0-2023-10-15"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* failing test due to Elixir version upgrade ([532852b](https://github.com/dkarter/cookie_monster/commit/532852b3cd65b5687f8efe5fa9a1d4114a1a4999))\n* return ArgumentError from `encode!` or `decode!` ([4f2d460](https://github.com/dkarter/cookie_monster/commit/4f2d46010544adf069aa0ee7904de14284dad3cd))\n* use of deprecated day_of_week/3 ([11812e9](https://github.com/dkarter/cookie_monster/commit/11812e9e8b8a3ed92b4ce6dc8f13bba7cf4f2d84))","ref":"changelog.html#bug-fixes"}],"content_type":"text/markdown"}